# Welcome to the Random Events package!

Probabilistic Machine Learning frequently requires descriptions of random variables and events
that are shared among many packages.
This package provides a common interface for describing random variables and events, using
usable and easily extensible classes.

Install the package via

```
pip install random-events
```

Read the docs [here.](https://random-events.readthedocs.io/en/latest/)
